// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:wyatt_architecture/src/core/exceptions/exceptions.dart';
import 'package:wyatt_architecture/src/domain/usecase.dart';

/// Usecase observers
mixin Observer<I, O> {
  /// Called before usecase is runned.
  /// Useful to check the preconditions
  FutureOr<void> onStart(I? params) {}
}

/// Exception observer
mixin ExceptionObserver<O> {
  /// Called on error
  /// Useful to handle exceptions
  FutureOr<void> onError(AppException e) {}
}

/// Completer observer
mixin CompleterObserver<O> {
  /// Called after usecase is runned.
  /// Useful to log the result
  FutureOr<void> onComplete(Res<O>? result) {}
}
