// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:io';

import 'package:json_annotation/json_annotation.dart';

part 'android_config.g.dart';

@JsonSerializable(
  anyMap: true,
  fieldRename: FieldRename.snake,
  checked: true,
)
class AndroidConfig {
  const AndroidConfig({
    required this.flutterArgs,
    required this.encryptedKeyFileName,
    required this.googleServiceAccountFileName,
    required this.releaseStatus,
    required this.androidFolderPath,
    required this.track,
    this.packageName,
  });

  factory AndroidConfig.fromJson(Map<dynamic, dynamic> json) =>
      _$AndroidConfigFromJson(json);

  Map<String, dynamic> toJson() => _$AndroidConfigToJson(this);

  static const defaultValues = AndroidConfig(
    flutterArgs: '',
    encryptedKeyFileName: 'android_keys.zip.gpg',
    googleServiceAccountFileName: 'service_account_key.json',
    releaseStatus: 'draft',
    track: 'internal',
    androidFolderPath: 'android',
  );

  final String? packageName;
  final String flutterArgs;
  final String encryptedKeyFileName;
  final String googleServiceAccountFileName;
  final String androidFolderPath;
  final String releaseStatus;
  final String track;

  File get encryptedKeyFile => File('$androidFolderPath/$encryptedKeyFileName');
  File get googleServiceAccountFile =>
      File('$androidFolderPath/$googleServiceAccountFileName');
  Directory get androidDirectory => Directory(androidFolderPath);
}
