// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:convert';
import 'dart:io';

import 'package:wyatt_continuous_deployment/src/core/injection/injectable.dart';
import 'package:wyatt_continuous_deployment/src/core/utils/logging.dart';
import 'package:wyatt_continuous_deployment/src/domain/entities/fastlane/fastlane_deploy_pilot_parameters.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/process_usecase.dart';

@usecase
class FastlaneDeployPilotUsecase
    extends ProcessUsecase<FastlaneDeployPilotParameters> {
  @override
  String get onCompletedMessage => 'Ipa deployed!';

  @override
  String get onErrorMessage => 'Error deploying ipa!';

  @override
  String get onStartedMessage => 'Deploying ipa...';

  @override
  Future<ProcessResult?> run(FastlaneDeployPilotParameters param) async {
    final file = File(param.appStoreConnectConfig.keyFilePath!);
    final content = file.readAsBytesSync();
    final key = utf8.decode(content);

    const executable = 'fastlane';
    final args = [
      'run',
      'pilot',
      'api_key:${jsonEncode(param.appStoreConnectConfig.toJson(key))}',
      ...param.toList(),
    ];

    logger.detail('Running: $executable ${args.join(' ')}');

    return Process.run(executable, args);
  }
}
