// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

/// {@template simple_icon_button_theme_extension}
/// Default simple icon button theme extension using Flutter's default values.
/// {@endtemplate}
class SimpleIconButtonThemeExtensionDefault
    extends SimpleIconButtonThemeExtension {
  /// {@macro simple_icon_button_theme_extension}
  const SimpleIconButtonThemeExtensionDefault({
    required super.disabledStyle,
    required super.focusedStyle,
    required super.hoveredStyle,
    required super.normalStyle,
    required super.tappedStyle,
  });

  /// Creates a [SimpleIconButtonThemeExtensionDefault] given a [ThemeData]
  ///
  /// {@macro file_selection_button_theme_extension}
  factory SimpleIconButtonThemeExtensionDefault.from(ThemeData theme) {
    final backgroundColor = MultiColor.single(theme.colorScheme.primary);
    final foregroundColor = MultiColor.single(theme.colorScheme.onPrimary);

    final style = SimpleIconButtonStyle(
      dimension: theme.buttonTheme.height,
      radius: (theme.buttonTheme.shape is RoundedRectangleBorder)
          ? (theme.buttonTheme.shape as RoundedRectangleBorder).borderRadius
          : null,
      padding: const EdgeInsets.all(5),
      foregroundColors: foregroundColor,
      backgroundColors: backgroundColor,
      animationDuration: Duration.zero,
    );

    return SimpleIconButtonThemeExtensionDefault(
      normalStyle: style,
      focusedStyle: style,
      hoveredStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(theme.colorScheme.primary.withOpacity(0.80)),
      ),
      tappedStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(theme.colorScheme.primary.withOpacity(0.75)),
      ),
      disabledStyle: style.copyWith(
        foregroundColors:
            MultiColor.single(theme.colorScheme.onSurface.withOpacity(0.12)),
        backgroundColors:
            MultiColor.single(theme.colorScheme.onSurface.withOpacity(0.38)),
      ),
    );
  }

  /// Creates a [SimpleIconButtonThemeExtensionDefault] from a dark theme
  factory SimpleIconButtonThemeExtensionDefault.dark() =>
      SimpleIconButtonThemeExtensionDefault.from(ThemeData.dark());

  /// Creates a [SimpleIconButtonThemeExtensionDefault] from a light theme
  factory SimpleIconButtonThemeExtensionDefault.light() =>
      SimpleIconButtonThemeExtensionDefault.from(ThemeData.light());
}
