// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

part 'pricing_card_component.g.dart';

class PricingLine {
  const PricingLine({
    required this.data,
    this.icon,
  });

  final TextWrapper data;
  final Widget? icon;

  @override
  String toString() => 'PricingLine(data: $data, icon: $icon)';
}

class Pricing {
  const Pricing({
    required this.price,
    this.period,
    this.hasAsterisk = false,
  });

  final TextWrapper price;
  final TextWrapper? period;

  /// If [hasAsterisk] is true then the price will be displayed with
  /// an asterisk to emphasize that it is a special price.
  final bool hasAsterisk;
}

@ComponentProxyExtension()
abstract class PricingCardComponent extends CardComponent
    with CopyWithMixin<$PricingCardComponentCWProxy> {
  const PricingCardComponent({
    this.axis,
    this.title,
    this.pricing,
    this.description,
    this.features,
    this.cta,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  /// Axis of the card
  ///
  /// If [axis] is [Axis.horizontal] then only the first icon will be displayed.
  /// Used in header of the card.
  final Axis? axis;

  /// Title of the card
  ///
  /// If [axis] is [Axis.vertical] then icon of the title will be displayed
  /// above the title.
  final PricingLine? title;

  /// Pricing of the card
  final Pricing? pricing;

  /// Description of the card
  final TextWrapper? description;

  /// List of special features of the card
  final List<PricingLine>? features;

  /// CTA of the card
  final Widget? cta;
}
