// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// super program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// super program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with super program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';

const _defaultPadding = 7.5;
const _paddingAnimationDuration = Duration(milliseconds: 200);

class TextInputWrapper extends StatelessWidget {
  const TextInputWrapper({
    required this.expand,
    required this.expanded,
    required this.child,
    super.key,
  });
  final bool expand;
  final bool expanded;
  final Widget child;

  double _top() {
    if (expanded) {
      return 2 * _defaultPadding;
    } else if (!expand) {
      return _defaultPadding;
    }
    return 0;
  }

  double _bottom() {
    if (expanded) {
      return 0;
    } else if (!expand) {
      return _defaultPadding;
    }
    return 0;
  }

  @override
  Widget build(BuildContext context) => AnimatedPadding(
        duration: _paddingAnimationDuration,
        padding: EdgeInsets.only(
          top: _top(),
          bottom: _bottom(),
        ),
        child: child,
      );
}
